var onThumbnailsClick;
var photosWipe = function(gallerySelector) {
	var parseThumbnailElements = function(el) {
		var thumbElements = el.childNodes,
			numNodes = thumbElements.length,
			items = [],
			el,
			childElements,
			thumbnailEl,
			size,
			item;

		for(var i = 0; i < numNodes; i++) {
			el = thumbElements[i];

			if(el.nodeType !== 1) {
			  continue;
			}

			childElements = el.children;

			size = el.getAttribute('data-size').split('x');

			item = {
				src: el.getAttribute('data-thumb'), //href
				w: parseInt(size[0], 10),
				h: parseInt(size[1], 10),
				author: el.getAttribute('data-author')
			};

			item.el = el; 

			if(childElements.length > 0) {
			  item.msrc = childElements[0].getAttribute('src');
			  if(childElements.length > 1) {
				  item.title = childElements[1].innerHTML;
			  }
			}


			var mediumSrc = el.getAttribute('data-med');
			if(mediumSrc) {
				size = el.getAttribute('data-med-size').split('x');
				item.m = {
					src: mediumSrc,
					w: parseInt(size[0], 10),
					h: parseInt(size[1], 10)
				};
			}
			item.o = {
				src: item.src,
				w: item.w,
				h: item.h
			};

			items.push(item);
		}

		return items;
	};

	var closest = function closest(el, fn) {
		return el && ( fn(el) ? el : closest(el.parentNode, fn) );
	};

	onThumbnailsClick = function(e) {
		e = e || window.event;
		e.preventDefault ? e.preventDefault() : e.returnValue = false;

		var eTarget = e.target || e.srcElement;
		
		var clickedListItem = closest(eTarget, function(el) {
			return el.tagName === 'SPAN'; //固定标签
		});

		if(!clickedListItem) {
			return;
		}

		var clickedGallery = clickedListItem.parentNode;
		//alert(clickedGallery.innerHTML);
		var childNodes = clickedListItem.parentNode.childNodes,
			numChildNodes = childNodes.length,
			nodeIndex = 0,
			index;
		
		for (var i = 0; i < numChildNodes; i++) {
			if(childNodes[i].nodeType !== 1) { 
				continue; 
			}

			if(childNodes[i] === clickedListItem) {
				index = nodeIndex;
				break;
			}
			nodeIndex++;
		}

		if(index >= 0) {
			//alert(numChildNodes+' '+index+' '+clickedGallery);
			openPhotoSwipe( index, clickedGallery );
		}
		return false;
	};

	var photoswipeParseHash = function() {
		var hash = window.location.hash.substring(1),		
		params = { };

		if(hash.length < 5) { // pid=1
			return params;
		}

		var vars = hash.split('&');
		for (var i = 0; i < vars.length; i++) {
			if(!vars[i]) {
				continue;
			}
			var pair = vars[i].split('=');  
			if(pair.length < 2) {
				continue;
			}           
			params[pair[0]] = pair[1];
		}

		if(params.gid) {
			params.gid = parseInt(params.gid, 10);
		}

		return params;
	};

	var openPhotoSwipe = function(index, galleryElement, disableAnimation, fromURL) {
		var pswpElement = document.querySelectorAll('.pswp')[0],
			gallery,
			options,
			items;

		items = parseThumbnailElements(galleryElement);

		// define options (if needed)
		options = {

			galleryUID: galleryElement.getAttribute('data-pswp-uid'),

			getThumbBoundsFn: function(index) {
				// See Options->getThumbBoundsFn section of docs for more info
				var thumbnail = items[index].el.children[0],
					pageYScroll = window.pageYOffset || document.documentElement.scrollTop,
					rect = thumbnail.getBoundingClientRect(); 

				return { x:rect.left, y:rect.top + pageYScroll, w:rect.width };
			},

			addCaptionHTMLFn: function(item, captionEl, isFake) {
				if(!item.title) {
					captionEl.children[0].innerText = '';
					return false;
				}
				captionEl.children[0].innerHTML = item.title +  '<br/><small>Photo: ' + item.author + '</small>';
				return true;
			}
			
		};


		if(fromURL) {
			if(options.galleryPIDs) {
				for(var j = 0; j < items.length; j++) {
					if(items[j].pid == index) {
						options.index = j;
						break;
					}
				}
			} else {
				options.index = parseInt(index, 10) - 1;
			}
		} else {
			options.index = parseInt(index, 10);
		}

		if( isNaN(options.index) ) {
			return;
		}



		var radios = document.getElementsByName('gallery-style');
		for (var i = 0, length = radios.length; i < length; i++) {
			if (radios[i].checked) {
				if(radios[i].id == 'radio-all-controls') {

				} else if(radios[i].id == 'radio-minimal-black') {
					options.mainClass = 'pswp--minimal--dark';
					options.barsSize = { top:0,bottom:0 };
					options.captionEl = false;
					options.fullscreenEl = false;
					options.shareEl = false;
					options.bgOpacity = 0.85;
					options.tapToClose = true;
					options.tapToToggleControls = false;
				}
				break;
			}
		}

		if(disableAnimation) {
			options.showAnimationDuration = 0;
		}

		gallery = new PhotoSwipe( pswpElement, PhotoSwipeUI_Default, items, options);

		var realViewportWidth,
			useLargeImages = false,
			firstResize = true,
			imageSrcWillChange;

		gallery.listen('beforeResize', function() {

			var dpiRatio = window.devicePixelRatio ? window.devicePixelRatio : 1;
			dpiRatio = Math.min(dpiRatio, 2.5);
			realViewportWidth = gallery.viewportSize.x * dpiRatio;


			if(realViewportWidth >= 1200 || (!gallery.likelyTouchDevice && realViewportWidth > 800) || screen.width > 1200 ) {
				if(!useLargeImages) {
					useLargeImages = true;
					imageSrcWillChange = true;
				}
				
			} else {
				if(useLargeImages) {
					useLargeImages = false;
					imageSrcWillChange = true;
				}
			}

			if(imageSrcWillChange && !firstResize) {
				gallery.invalidateCurrItems();
			}

			if(firstResize) {
				firstResize = false;
			}

			imageSrcWillChange = false;

		});

		gallery.listen('gettingData', function(index, item) {
			if( useLargeImages ) {
				item.src = item.o.src;
				item.w = item.o.w;
				item.h = item.o.h;
			} else {
				item.src = item.m.src;
				item.w = item.m.w;
				item.h = item.m.h;
			}
		});

		gallery.init();
	};

	var galleryElements = document.querySelectorAll( gallerySelector );
	for(var i = 0, l = galleryElements.length; i < l; i++) {
		galleryElements[i].setAttribute('data-pswp-uid', i+1);
		galleryElements[i].onclick = onThumbnailsClick;
		JQ(galleryElements[i]).on('click',onThumbnailsClick);
	}

	var hashData = photoswipeParseHash();
	//alert(JSON.stringify(hashData));
	if(hashData.pid && hashData.gid) {
		openPhotoSwipe( hashData.pid,  galleryElements[ hashData.gid - 1 ], true, true );
	}
};

function InitImgAuto(oid,span){ //初始化多图
	LoadImgInitHtml();
	var o=JQ(oid).find('img'),win=JQ(window);
	o.each(function(i,obj){
		var tag=o.eq(i).parent().parent().prop("tagName").toLowerCase(),str='',src=o.eq(i).attr('src'),img;
		img=new Image();
		img.src=src;
		//alert(img.width+' '+img.height);
		img.onload=function(){
			var h=parseInt(img.height/(img.width/win.width()));
			if(tag!=span){			
				str='<a href="'+src+'" data-size="'+(win.width()*2)+'x'+(h*2)+'" data-med="'+src+'" data-med-size="'+(img.width)+'x'+(img.height)+'"><img src="'+src+'"></a>';
				o.eq(i).before(str).remove();
			}else{
				o.eq(i).parent().parent().attr({'data-size':(win.width()*2)+'x'+(h*2),'data-med-size':(img.width)+'x'+(img.height)});
			}
		};
	});
	photosWipe(oid);
	//if((PhoneType()=='iPhone' || PhoneType()=='iPad') && window.navigator.userAgent.indexOf('Appcan')>-1)JQ('.pswp').css('top','20px'); //处理APP顶部的距离
}//InitImgAuto end

function LoadImgInitHtml(){ //<!-- 图片展示框代码开始 -->
	if(JQ('body .pswp').size())return false; //只加载一次
	var iphone=PhoneType();
	var str='<div class="pswp" tabindex="-1" role="dialog" aria-hidden="true">';
		str+='<div class="top0 right0 bottom0 w30em h30em pos2 fr zindex98" onClick="JQ(\'.pswp__button--close\').trigger(\'click\');"></div>';
		str+='<div class="pswp__bg"></div>';
		str+='<div class="pswp__scroll-wrap">';
			str+='<div class="pswp__container">';
				str+='<div class="pswp__item"></div>';
				str+='<div class="pswp__item"></div>';
				str+='<div class="pswp__item"></div>';
			str+='</div>';			
			str+='<div class="pswp__ui pswp__ui--hidden">';
				
				str+='<div class="pswp__top-bar">'; //WAP上不需要右边的了'+((iphone=='iPhone' || iphone=='iPad') ? ' style="margin-top:20px;"' : '')+'
					str+='<div class="pswp__counter"></div>';					
					str+='<button class="pswp__button pswp__button--close" title="Close(Esc)" onClick1="JQ(\'.pswp\').remove();"><font style="font-size:1.2em;color:#cccccc;" class="pevent">×</font></button>'; //<img src="/public/plugin/photo_slide/css/close.png" class="pevent" />
					//str+='<button class="pswp__button pswp__button--share" title="Share"></button>';
					//str+='<button class="pswp__button pswp__button--fs" title="Toggle fullscreen"><img class="full" src="/public/plugin/photo_slide/css/full.png" /><img class="outfull hide" src="/public/plugin/photo_slide/css/full_out.png" /></button>';
					str+='<button class="pswp__button pswp__button--zoom" title="Zoom in/out"></button>';
					str+='<div class="pswp__preloader">';
						str+='<div class="pswp__preloader__icn">';
						  str+='<div class="pswp__preloader__cut">';
							str+='<div class="pswp__preloader__donut"></div>';
						  str+='</div>';
						str+='</div>';
					str+='</div>';
				str+='</div>';
	
				str+='<div class="pswp__share-modal pswp__share-modal--hidden pswp__single-tap">';
					str+='<div class="pswp__share-tooltip"></div> ';
				str+='</div>';
	
				str+='<button class="pswp__button pswp__button--arrow--left" title="Previous (arrow left)">';
				str+='</button>';
				str+='<button class="pswp__button pswp__button--arrow--right" title="Next (arrow right)">';
				str+='</button>';
				
				str+='<div class="pswp__caption"><div class="pswp__caption__center"></div></div>';
			str+='</div>';
		str+='</div>';
	str+='</div>';
	JQ('body').append(str);
}